@@ -1,6 +1,6 @@
 ;;; modus-vivendi-deuteranopia-theme.el --- Deuteranopia-optimized theme with a black background -*- lexical-binding:t -*-
 
-;; Copyright (C) 2019-2025  Free Software Foundation, Inc.
+;; Copyright (C) 2019-2026  Free Software Foundation, Inc.
 
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
 ;; Maintainer: Protesilaos Stavrou <info@protesilaos.com>
@@ -26,35 +26,42 @@
 ;;
 ;; The Modus themes conform with the highest standard for
 ;; color-contrast accessibility between background and foreground
-;; values (WCAG AAA).  Please refer to the official Info manual for
-;; further documentation (distributed with the themes, or available
-;; at: <https://protesilaos.com/emacs/modus-themes>).
+;; values (WCAG AAA).  They are also highly customizable and can even
+;; be used as the basis for other themes.  Please refer to the official
+;; Info manual for further documentation (distributed with the themes,
+;; or available at: <https://protesilaos.com/emacs/modus-themes>).
 
 ;;; Code:
 
 
 
-(eval-and-compile
-  (unless (and (fboundp 'require-theme)
-               load-file-name
-               (equal (file-name-directory load-file-name)
-                      (expand-file-name "themes/" data-directory))
-               (require-theme 'modus-themes t))
-    (require 'modus-themes))
-  
-  (defcustom modus-vivendi-deuteranopia-palette-user nil
-    "Like the `modus-vivendi-deuteranopia-palette' for user-defined entries.
+(unless (and (fboundp 'require-theme)
+             load-file-name
+             (equal (file-name-directory load-file-name)
+                    (expand-file-name "themes/" data-directory))
+             (require-theme 'modus-themes t))
+  (require 'modus-themes))
+
+;;;###theme-autoload
+(deftheme modus-vivendi-deuteranopia
+  "Deuteranopia-optimized theme with a black background."
+  :background-mode 'dark
+  :kind 'color-scheme
+  :family 'modus)
+
+(defcustom modus-vivendi-deuteranopia-palette-user nil
+  "Like the `modus-vivendi-deuteranopia-palette' for user-defined entries.
 This is meant to extend the palette with custom named colors and/or
 semantic palette mappings.  Those may then be used in combination with
 palette overrides (also see `modus-themes-common-palette-overrides' and
 `modus-vivendi-deuteranopia-palette-overrides')."
-    :group 'modus-themes
-    :package-version '(modus-themes . "4.5.0")
-    :type '(repeat (list symbol (choice symbol string)))
-    :link '(info-link "(modus-themes) Option to extend the palette for use with overrides"))
+  :group 'modus-themes
+  :package-version '(modus-themes . "4.5.0")
+  :type '(repeat (list symbol (choice symbol string)))
+  :link '(info-link "(modus-themes) Option to extend the palette for use with overrides"))
 
-  (defcustom modus-vivendi-deuteranopia-palette-overrides nil
-    "Overrides for `modus-vivendi-deuteranopia-palette'.
+(defcustom modus-vivendi-deuteranopia-palette-overrides nil
+  "Overrides for `modus-vivendi-deuteranopia-palette'.
 
 Mirror the elements of the aforementioned palette, overriding
 their value.
@@ -68,25 +75,26 @@ mappings, such as to make the cursor red.  Wherea theme-specific
 overrides can also be used to change the value of a named color,
 such as what hexadecimal RGB value the red-warmer symbol
 represents."
-    :group 'modus-themes
-    :package-version '(modus-themes . "4.0.0")
-    :version "30.1"
-    :type '(repeat (list symbol (choice symbol string)))
-    :link '(info-link "(modus-themes) Palette overrides"))
+  :group 'modus-themes
+  :package-version '(modus-themes . "4.0.0")
+  :version "30.1"
+  :type '(repeat (list symbol (choice symbol string)))
+  :link '(info-link "(modus-themes) Palette overrides"))
 
-  (modus-themes-theme
-    modus-vivendi-deuteranopia
-    modus-themes
-    "Deuteranopia-optimized theme with a black background.
+(modus-themes-theme
+ 'modus-vivendi-deuteranopia
+ 'modus-themes
+ "Deuteranopia-optimized theme with a black background.
 This variant is optimized for users with red-green color
 deficiency (deuteranopia).  It conforms with the highest
 legibility standard for color contrast between background and
 foreground in any given piece of text, which corresponds to a
 minimum contrast in relative luminance of 7:1 (WCAG AAA
 standard)."
-    dark
-    modus-themes-vivendi-deuteranopia-palette
-    modus-vivendi-deuteranopia-palette-user
-    modus-vivendi-deuteranopia-palette-overrides))
+ 'dark
+ 'modus-themes-vivendi-deuteranopia-palette
+ 'modus-vivendi-deuteranopia-palette-user
+ 'modus-vivendi-deuteranopia-palette-overrides
+ 'modus-themes-faces-deuteranopia)
 
 ;;; modus-vivendi-deuteranopia-theme.el ends here
