@@ -42,6 +42,13 @@
              (require-theme 'modus-themes t))
   (require 'modus-themes))
 
+;;;###theme-autoload
+(deftheme modus-vivendi-tritanopia
+  "Tritanopia-optimized theme with a black background."
+  :background-mode 'dark
+  :kind 'color-scheme
+  :family 'modus)
+
 (defcustom modus-vivendi-tritanopia-palette-user nil
   "Like the `modus-vivendi-tritanopia-palette' for user-defined entries.
 This is meant to extend the palette with custom named colors and/or
